@@ -19,12 +19,12 @@
 
 #include "evolutionsettings.h"
 #include "evolutionutil.h"
-#include "MailCommon/MailUtil"
+#include <MailCommon/MailUtil>
 #include <ImportWizard/ImportWizardUtil>
 
 #include <KIdentityManagement/kidentitymanagement/identity.h>
 
-#include <mailtransport/transportmanager.h>
+#include <MailTransport/TransportManager>
 
 #include "evolutionv3plugin_debug.h"
 
